database

package
v0.0.0-...-0fdeed9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 21, 2019 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

DB is the global database connection pool used by the rest of the application.

Functions

func CloseConnection

func CloseConnection() error

CloseConnection closes the active database connection.

func DisableLogging

func DisableLogging()

DisableLogging disables the logging from the database for production enviroments.

func EnableLogging

func EnableLogging()

EnableLogging enables the logging from the database for debug enviroments.

func Init

func Init(username, password, host, database string) error

Init the global database connection pool.

Types

This section is empty.

Jump to