Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DB sqlbuilder.Database
DB is the global database connection pool used by the rest of the application.
Functions ¶
func CloseConnection ¶
func CloseConnection() error
CloseConnection closes the active database connection.
func DisableLogging ¶
func DisableLogging()
DisableLogging disables the logging from the database for production enviroments.
func EnableLogging ¶
func EnableLogging()
EnableLogging enables the logging from the database for debug enviroments.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.