Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func New ¶
New initializes the error, and optionally logs the error to the console depending on the severity.
func NewFromError ¶
NewFromError initializes an NGError from an external error.
func SetMinimumSeverity ¶
func SetMinimumSeverity(severity Severity)
SetMinimumSeverity sets the minimum severity level for which errors will be logged.
Types ¶
type Severity ¶
type Severity int
Severity is used to denote the severity of a generated error.
const ( // SeverityOK means that a generated error is OK, and is very unlikely to impact software effectiveness. SeverityOK Severity = 0 // SeverityWarning means that a generated error has the potential to impact software effectiveness. SeverityWarning Severity = 1 // SeverityFatal means that a generated error has impacted software effectivness. SeverityFatal Severity = 2 )
Click to show internal directories.
Click to hide internal directories.